/****************************************************************************\
**  Title:       DCXHEAD.C                                                  **
**  Purpose:     Display the data in a DCX image file header.               **
**  Version:     1.0                                                        **
**  Date:        April 1991                                                 **
**  Author:      James D. Murray, Anaheim, CA, USA                          **
**  C Compilers: Borland C++ v2.0, Microsoft C v6.00a                       **
**                                                                          **
**  DCX2PCX extracts all the PCX images from within a DCX file.  A DCX file **
**  may contain up to 1023 images.  Each PCX image is a complete PCX image  **
**  file, including header, palette, and compressed image data.             **
**                                                                          **
**  Copyright (C) 1991 by Graphics Software Labs.  All rights reserved.     **
\****************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "endianio.h"
#include "pcx.h"

DWORD (*GetDword)(FILE *);      /* Pointer to ENDIANIO function */


int
main(argc, argv)
int argc;
char *argv[];
{
    WORD       counter;         /* Number of PCX images in DCX file     */
    FILE      *fpDcx;           /* File pointer to the DCX image file   */
    CHAR       dcxFileName[81]; /* Holder for the DCX image file name   */
    DCXHEADER  dcxHead;         /* DCX image file header structure      */

    puts("DCXHEAD - Display the header info within a DCX image file (v1.00)\n");


    /* Check for proper number of command line arguments */
    if (argc < 2)
    {
        fputs("Usage: DCXHEAD filename.dcx\n\n", stderr);
        exit(-1);
    }

    /* Add the .dcx extension to the file name if no extension exists */
    strncpy(dcxFileName, argv[1], 80);
    if (!strrchr(argv[1], '.'))
        strcat(dcxFileName, ".dcx");

    /* Open the DCX image file */
    if ((fpDcx = fopen(dcxFileName, "rb")) == NULL)
    {
        fprintf(stderr, "DCXHEAD: Cannot open file %s\n", dcxFileName);
        exit(-2);
    }

    /* Read using little-endian byte order */
    GetDword = GetLittleDword;

    /* Read the ID word */
    dcxHead.Id = GetDword(fpDcx);

    /* Check the identification word value */
    if (dcxHead.Id != 987654321L)
    {
        fprintf(stderr, "DCXHEAD: %s is not a DCX-format file!\n", dcxFileName);

        exit(-3);
    }
    printf("Magic number: %ld\n\n", dcxHead.Id);

    /* Zero-out the page list */
    memset(&dcxHead.PageList, 0, sizeof(dcxHead.PageList));

    /* Read the page list one entry at a time */
    for (counter = 0; dcxHead.PageList[counter] = GetDword(fpDcx); counter++)
        printf("PCX Image %d Offset: %ld\n",
          counter + 1, dcxHead.PageList[counter]);

    printf("\nTotal Number of PCX images in DCX file %s: %u\n",
      dcxFileName, counter);

    /* Check for FILE stream errors */
    if (ferror(fpDcx))
    {
        fputs("DCXHEAD: Error reading header information!\n", stderr);
        exit(-3);
    }
    return(0);              /* Successful termination */
}
}
